Loss Reserving Module
=====================

The loss reserving module will provide general insurance reserving methods.

.. automodule:: actuneo.loss_reserving
   :members:
   :undoc-members:
   :show-inheritance:

.. note::
   This module is under development. Contributions are welcome!

Planned Features
----------------

* Chain-ladder method
* Bornhuetter-Ferguson technique
* Cape Cod method
* Stochastic reserving models
* Loss development triangles
* IBNR estimation

